@@ -6,13 +6,21 @@ import tempfile
 import contextlib
 from pathlib import Path
 from urllib.parse import urlparse
-from _thread import RLock  # type: ignore
-from . import settings
 
 
 # General
 
 
+def path_asset(*paths):
+    return os.path.join(os.path.dirname(__file__), "assets", *paths)
+
+
+def read_asset(*paths):
+    dirname = os.path.dirname(__file__)
+    with open(os.path.join(dirname, "assets", *paths)) as file:
+        return file.read().strip()
+
+
 def with_format(path, format):
     suffix = f".{format}" if format else ""
     return str(Path(path).with_suffix(suffix))
@@ -31,11 +39,24 @@ def read_file(source, *, default=None):
         return file.read()
 
 
+def copy_file(source, target):
+    if isinstance(source, (tuple, list)):
+        source = os.path.join(*source)
+    if isinstance(target, (tuple, list)):
+        target = os.path.join(*target)
+    ensure_dir(target)
+    shutil.copy(source, target)
+
+
 def move_file(source, target):
     ensure_dir(target)
     shutil.move(source, target)
 
 
+def remove_dir(path):
+    shutil.rmtree(path)
+
+
 def write_file(path, text=""):
     with tempfile.NamedTemporaryFile("wt", delete=False, encoding="utf-8") as file:
         file.write(text)
@@ -96,57 +117,3 @@ def extract_classes(module, Parent):
 
 def order_objects(objects, property):
     return list(sorted(objects, key=lambda obj: -getattr(obj, property)))
-
-
-# Backports
-
-
-class cached_property:
-    # It can be removed after dropping support for Python 3.6 and Python 3.7
-
-    def __init__(self, func):
-        self.func = func
-        self.attrname = None
-        self.__doc__ = func.__doc__
-        self.lock = RLock()
-
-    def __set_name__(self, owner, name):
-        if self.attrname is None:
-            self.attrname = name
-        elif name != self.attrname:
-            raise TypeError(
-                "Cannot assign the same cached_property to two different names "
-                f"({self.attrname!r} and {name!r})."
-            )
-
-    def __get__(self, instance, owner=None):
-        if instance is None:
-            return self
-        if self.attrname is None:
-            raise TypeError(
-                "Cannot use cached_property instance without calling __set_name__ on it."
-            )
-        try:
-            cache = instance.__dict__
-        except AttributeError:  # not all objects have __dict__ (e.g. class defines slots)
-            msg = (
-                f"No '__dict__' attribute on {type(instance).__name__!r} "
-                f"instance to cache {self.attrname!r} property."
-            )
-            raise TypeError(msg) from None
-        val = cache.get(self.attrname, settings.UNDEFINED)
-        if val is settings.UNDEFINED:
-            with self.lock:
-                # check if another thread filled cache while we awaited lock
-                val = cache.get(self.attrname, settings.UNDEFINED)
-                if val is settings.UNDEFINED:
-                    val = self.func(instance)
-                    try:
-                        cache[self.attrname] = val
-                    except TypeError:
-                        msg = (
-                            f"The '__dict__' attribute on {type(instance).__name__!r} instance "
-                            f"does not support item assignment for caching {self.attrname!r} property."
-                        )
-                        raise TypeError(msg) from None
-        return val
