@@ -6,8 +6,11 @@ from ..html.renderer import HtmlExtension
 from ...plugin import Plugin
 
 
+# TODO: rename markdown class to livemark-markdown (as in pagination)
+
+
 class MarkupPlugin(Plugin):
-    name = "markup"
+    identity = "markup"
 
     # Process
 
