@@ -1,10 +1,10 @@
 import os
 import pkgutil
 import importlib
-from .exception import LivemarkException
-from .helpers import cached_property
+from cached_property import cached_property
 from .plugin import Plugin
 from . import helpers
+from . import errors
 
 
 class System:
@@ -24,7 +24,7 @@ class System:
         """Registered plugins
 
         Returns:
-            dict[]: a list of plugin structures
+            dict: plugins mapping
         """
         Plugins = {}
         modules = []
@@ -38,20 +38,31 @@ class System:
             modules.append(module)
         for module in modules:
             for Class in helpers.extract_classes(module, Plugin):
-                if Class.name in Plugins:
-                    raise LivemarkException(f"Plugin name conflict: {Class.name}")
-                Plugins[Class.name] = Class
+                if Class.identity in Plugins:
+                    raise errors.Error(f"Plugin identity conflict: {Class.identity}")
+                Plugins[Class.identity] = Class
         return Plugins
 
+    # Manage
+
+    def iterate(self):
+        """Iterate plugins by priority
+
+        Returns:
+            type[]: list of plugin classes
+        """
+        objects = self.Plugins.values()
+        return helpers.order_objects(objects, "priority")
+
     def register(self, Plugin):
         """Register a plugin
 
         Parameters:
             Plugin (type): a plugin class to register
         """
-        if Plugin.name in self.Plugins:
-            raise LivemarkException(f"Plugin name conflict: {Plugin.name}")
-        self.Plugins[Plugin.name] = Plugin
+        if Plugin.identity in self.Plugins:
+            raise errors.Error(f"Plugin identity conflict: {Plugin.identity}")
+        self.Plugins[Plugin.identity] = Plugin
 
     def deregister(self, Plugin):
         """Deregister a plugin
@@ -59,9 +70,9 @@ class System:
         Parameters:
             Plugin (type): a plugin class to register
         """
-        if Plugin.name not in self.Plugins:
-            raise LivemarkException(f"Not registered plugin: {Plugin.name}")
-        del self.Plugins[Plugin.name]
+        if Plugin.identity not in self.Plugins:
+            raise errors.Error(f"Not registered plugin: {Plugin.identity}")
+        del self.Plugins[Plugin.identity]
 
 
 system = System()
